@@ -48,6 +48,8 @@ from .enums import (
     OutagesTypes,
     Platform,
     PricesIndexes,
+    SupplyDemandMetric,
+    SupplyDemandSplit,
     TradesStatus,
     VesselTypesCPP,
     VesselTypesDry,
@@ -114,4 +116,6 @@ __all__ = [
     "InventoriesPeriod",
     "InventoriesSplit",
     "DiversionsVesselState",
+    "SupplyDemandMetric",
+    "SupplyDemandSplit",
 ]
