@@ -10,6 +10,7 @@ from kpler.sdk.helpers import (
     process_bool_parameter,
     process_date_parameter,
     process_enum_parameter,
+    process_enum_parameters,
     process_list_parameter,
 )
 
@@ -39,6 +40,8 @@ class FleetMetricsVessels(KplerClient):
         products: Optional[List[str]] = None,
         unit: Optional[Enum] = None,
         with_freight_view: bool = False,
+        vessel_types: Optional[List[str]] = None,
+        vessel_types_alt: Optional[List[str]] = None,
     ):
 
         """
@@ -53,6 +56,8 @@ class FleetMetricsVessels(KplerClient):
             products: Optional[str] Names of products. Not available on LNG platform
             unit: Optional[Enum] ``FleetMetricsVesselsMeasurementUnit`` by default return in bbl unit or cm on LNG platform
             with_freight_view: bool By default: with_freight_view=False. Provides access to the entire fleet's trades, irrespective of your current cargo subscription. Only available via Freight subscription.
+            vessel_types: Optional[List[str]] = Names of vessel types
+            vessel_types_alt: Optional[List[str]] = Names of vessel types for oil liquids platform only
 
         Examples:
 
@@ -95,6 +100,8 @@ class FleetMetricsVessels(KplerClient):
             "products": process_list_parameter(products),
             "unit": process_enum_parameter(unit),
             "withFreightView": process_bool_parameter(with_freight_view),
+            "vesselTypes": process_enum_parameters(vessel_types, to_lower_case=False),
+            "vesselTypesAlt": process_enum_parameters(vessel_types_alt, to_lower_case=False),
         }
         return self._get_dataframe(self.RESOURCE_NAME, query_parameters)
 
